@@ -728,7 +728,7 @@ class Sentinel1Reader:
 
                 noise_lut_azi_raw_ds[vari].attrs["description"] = hihi
             tmp.append(noise_lut_azi_raw_ds)
-        ds = xr.concat(tmp, pd.Index(pols, name="pol"))
+        ds = xr.concat(tmp, pd.Index(pols, name="pol", dtype=object))
         ds.attrs["history"] = "\n".join(history)
         return ds
 
@@ -767,7 +767,7 @@ class Sentinel1Reader:
                     )
                 )
             tmp.append(noise_lut_range_raw_ds)
-        ds = xr.concat(tmp, pd.Index(pols, name="pol"))
+        ds = xr.concat(tmp, pd.Index(pols, name="pol", dtype=object))
         ds.attrs["history"] = "\n".join(history)
         return ds
 
